#
# spec file for package mcelog
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           mcelog
Version:        195
Release:        150500.3.3.1
Summary:        Log Machine Check Events
License:        GPL-2.0-only
Group:          System/Monitoring
URL:            https://mcelog.org/
Source:         mcelog-%{version}.tar.gz
Source2:        mcelog.sysconfig
Source3:        mcelog.systemd
Source5:        mcelog.tmpfiles
Source6:        README.email_setup
Patch1:         email.patch
Patch2:         mcelog_invert_prefill_db_warning.patch
Patch3:         Start-consolidating-AMD-specific-stuff.patch
Patch4:         add_new_amd_cpu_defines
Patch5:         patches/add-f10h-support.patch
Patch6:         patches/add-f11h-support.patch
Patch7:         patches/add-f12h-support.patch
Patch8:         patches/add-f14h-support.patch
Patch9:         patches/add-f15h-support.patch
Patch10:        patches/add-f16h-support.patch
Patch11:        mcelog-socket-path.patch
Patch12:        fix_setgroups_missing_call.patch
BuildRequires:  libesmtp-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(systemd)
Requires:       logrotate
Requires(pre):  %fillup_prereq
ExclusiveArch:  %{ix86} x86_64
%{?systemd_requires}

%description
mcelog retrieves machine check events from an x86-64 kernel in a cron
job, decodes them, and logs them to %{_localstatedir}/log/mcelog.

A machine check event is a hardware error detected by the CPU.
It should run on any x86-64 system.

In addition, it allows decoding machine check kernel panic messages.

%prep
%autosetup

%build
echo "%{version}" > .os_version
%make_build CFLAGS="%{optflags} -fpie -pie"

%install
export prefix=%{buildroot}%{_prefix}
export etcprefix=%{buildroot}
make -e install
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
install -m644 mcelog.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/mcelog

mkdir -p %{buildroot}%{_fillupdir}
install -m 644 %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.mcelog

mkdir -p %{buildroot}/%{_docdir}/%{name}
install -m 644 %{SOURCE6} %{buildroot}/%{_docdir}/%{name}/README.email_setup
install -m 644 lk10-mcelog.pdf %{buildroot}/%{_docdir}/%{name}/lk10-mcelog.pdf
install -D -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/mcelog.service
install -D -m 0644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/mcelog.conf
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcmcelog

%pre
%service_add_pre %{name}.service

%post
%fillup_only
%service_add_post %{name}.service
%{?tmpfiles_create:%tmpfiles_create %{_tmpfilesdir}/mcelog.conf}

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr (-,root,root,755)
%{_mandir}/man8/*
%{_mandir}/man5/*
%{_sbindir}/mcelog
%config %{_sysconfdir}/logrotate.d/mcelog
%dir %{_sysconfdir}/mcelog
%config %{_sysconfdir}/mcelog/mcelog.conf
%{_fillupdir}/sysconfig.mcelog
%{_sysconfdir}/mcelog/*trigger
%{_unitdir}/mcelog.service
%{_tmpfilesdir}/mcelog.conf
%{_docdir}/%{name}
%{_sbindir}/rcmcelog
%ghost /run/mcelog

%changelog
* Tue Sep 12 2023 trenn@suse.de
- This contains following features:
  PED-6122
  [GNR] RAS: mcelog Add support for Granite Rapids (ALP)
  PED-6102
  [GNR] RAS: mcelog Add support for Granite Rapids (SLE 15 SP6)
  PED-6021
  [SRF] RAS: mcelog support for Sierra Forest (SLE 15 SP6)
  PED-6050
  [SRF] RAS: mcelog support for Sierra Forest (ALP)
- Change git repo in _service file from git to https url
- Update to version 195:
  * mcelog: Wire up model-specific decoding for Sierra Forest
  * mcelog: Add model-specific decoding for Granite Rapids
  * client.c: fix build w/ musl libc
  * mcelog: New model number for Arrowlake
  * mcelog: Don't overwrite model number when lookup fails
  * mcelog: Add Graniterapids, Grandridge and Sierraforest
  * mcelog: New model number for Lunarlake
  * mcelog: Add Emerald Rapids
  * Update PFA_test_howto
- Adopt to mainline:
  M email.patch
* Wed Jun 14 2023 trenn@suse.de
- Update to version 194 (jsc#PED-4218):
  * client.c: fix build w/ musl libc
  * mcelog: New model number for Arrowlake
  * mcelog: Don't overwrite model number when lookup fails
  * mcelog: Add Graniterapids, Grandridge and Sierraforest
  * mcelog: New model number for Lunarlake
  * mcelog: Add Emerald Rapids
  * mcelog: Add decode support for Sapphire Rapids
  * Update PFA_test_howto
  * mcelog: Add support for Meteor Lake
* Thu Oct  6 2022 trenn@suse.de
- Includes following SLE 15 SP5 jira features:
  * jsc#PED-671 mcelog: Update to latest release
  * jsc#PED-686 [CPU Features] Update mcelog support for ADL-N
  * jsc#PED-638 [CPU Features] Update mcelog support for MTL-P
- Update to version 189:
  * mcelog: Add another Raptor Lake CPU model
  * Fix generation of cputype files
  * mcelog: Add missing model numbers for Broadwell and Raptorlake
  * mcelog: Makefile: Only touch cputype.h if needed to create it
  * Makefile: add install-nodoc target
  * Use env as the shebang target
  * Add missing dependencies for cputype include files
  * mcelog: Reverse sens of check to call resolveaddr()
  * mcelog: Reverse the sense of the check to set memory_error_support
  * mcelog: Drop CASE_INTEL define
  * mcelog: Generate cpu_choices[] from table
  * mcelog: Generate the cputype_name[] array from the table
  * mcelog: Add CPU model numbers to table and generate switch function
  * mcelog: Generate CPU_* enums from a table
  * mcelog: Add two more Alderlake model numbers
  * mcelog: Reduce default threshold for corrected error page offline
  * Make genconfig use python3
  * mcelog: Add support for Raptorlake
  * Fix warnings in sysfs.c
  * mcelog: Change "DDR4" string to "DDR" for i10nm platforms
  * Fix logrotate syntax
  * remove outdated mcelog.conf.5 manual file
  * add furture print function for Python2
  * fix python errors in genconfig.py
  * fix the buf not freed in read_field
  * mcelog: Print warning for locked down kernel
  * mcelog: Handle sysfs files without length
- Had to adopt to latest CPU identification model
  mainline patch:
  b54ee05056a76e mcelog: Drop CASE_INTEL define
  and friends
  A    add_new_amd_cpu_defines
  D    add-defines.patch
  M    Start-consolidating-AMD-specific-stuff.patch
  M    add-f10h-support.patch
  M    add-f11h-support.patch
  M    add-f12h-support.patch
  M    add-f14h-support.patch
  M    add-f15h-support.patch
  M    add-f16h-support.patch
  M    email.patch
  M    fix_setgroups_missing_call.patch
* Tue May  3 2022 moritz.kodytek@suse.com
- Update to version 181:
  * mcelog: Add support for Raptorlake
- Adopt patches to latest git version
  M    Start-consolidating-AMD-specific-stuff.patch
  M    add-f10h-support.patch
  M    add-f11h-support.patch
  M    add-f12h-support.patch
  M    add-f14h-support.patch
  M    add-f15h-support.patch
  M    add-f16h-support.patch
  M    email.patch
  M    fix_setgroups_missing_call.patch
  M    mcelog_invert_prefill_db_warning.patch
- Use Python3 shebang instead of python
  A    python3_shebang
- Use Github URL
* Wed Apr 13 2022 moritz.kodytek@suse.com
- Update to version 180:
  * Fix warnings in sysfs.c
  * mcelog: Change "DDR4" string to "DDR" for i10nm platforms
  * Fix logrotate syntax
  * remove outdated mcelog.conf.5 manual file
  * add furture print function for Python2
  * fix python errors in genconfig.py
  * fix the buf not freed in read_field
  * mcelog: Print warning for locked down kernel
  * mcelog: Handle sysfs files without length
  * Fix make test fail
* Wed Sep  1 2021 trenn@suse.de
- Update to version 178:
  * mcelog: Fix typo/thinko in yellow cache change
* Mon Jul 19 2021 trenn@suse.de
- Update to version 177:
  * README: Mark up filename as code/monospace
  * README: Correct filename of `.os_version`
* Fri Jul  9 2021 trenn@suse.de
- Update to version 177 (jsc#SLE-18903):
  * mcelog: Update MSCOD error bit descriptions to match SDM
  * mcelog: Fix issues with "yellow" cache offlining
  * Add reference to Linux::MCELog
  * test: avoid the pfa test hang
- Add _service git magic
* Thu Apr  1 2021 yaroslav.kurlaev@gmail.com
- Remove deprecated "StandardOutput=syslog" option from the systemd
  unit file to remove a warning from systemd. (bsc#1185151)
* Tue Jan 26 2021 trenn@suse.de
- Update to version 175 (jsc#SLE-14450):
  * mcelog: Add a test case to test page error counter replacement.
  * mcelog: Use 'num-errors' to specify the number of mce records to be injected.
  * mcelog: Report how often the replacement of page CE counter happened
  * mcelog: Limit memory consumption for counting CEs per page
  * mcelog: Add support for Sapphirerapids server. (jsc#SLE-14450)
  * mcelog: i10nm: Fix mapping from bank number to functional unit
- Only refreshing patches, due to tarball modifications:
  M    Start-consolidating-AMD-specific-stuff.patch
  M    add-f10h-support.patch
  M    add-f11h-support.patch
  M    add-f12h-support.patch
  M    add-f14h-support.patch
  M    add-f15h-support.patch
  M    add-f16h-support.patch
  M    email.patch
  M    fix_setgroups_missing_call.patch
  M    mcelog_invert_prefill_db_warning.patch
* Mon Sep 28 2020 trenn@suse.de
- jsc#SLE-13505, jsc#SLE-13494
- Update to version 173:
  * mcelog: Rebalance the red-black tree after inserting a new node
  * mcelog: Add Tigerlake, Rocketlake, Alderlake, Lakefield
  * mcelog.service: Check existence of `/dev/mcelog` in systemd
  * mcelog.service: Remove DefaultStandardOutput configuration
  * mcelog: Add decode for MCi_MISC from 10nm memory controller
  * Add reporter tracking to trigger-invoking functions.
  * mcelog: Add "kflags" field to "struct mce"
* Sun Aug 16 2020 dmueller@suse.com
- update to 170:
  * mcelog: Add Cometlake client model numbers
  * mcelog: Do not start mcelog service if edac_mce_amd module is loaded
  * mcelog: Decode and print stepping from cpuid
  * mcelog: Add "kflags" field to "struct mce"
  * Add reporter tracking to trigger-invoking functions.
  * mcelog: Add decode for MCi_MISC from 10nm memory controller
- covers:
  * jsc#SLE-12689
* Wed Nov 20 2019 trenn@suse.de
- Update to version 1.66 (jira SLE-10087, jira SLE-8853):
  * mcelog: Add support for Icelake server, Icelake-D, and Snow Ridge
  M email.patch
-> Patched with fuzz, refresh needed
* Tue Oct 29 2019 trenn@suse.de
- Update to version 1.65:
  * mcelog: Add Cascade Lake to supported models
* Fri Sep 13 2019 jdelvare@suse.com
- mcelog.systemd: Preload the dmi-sysfs kernel module.
  When /dev/mem can't be read (which is the case when booting in
  Secure Mode), mcelog can use the dmi-sysfs interface instead,
  however for that the kernel module needs to be loaded first
  (bsc#1149186).
* Fri Sep  6 2019 MMuschner@suse.com
- Update to version 1.64:
  * mcelog: Add Icelake client model numbers.
  * add Hygon Dhyana support to not use mcelog, as Hygon Dhyana(0x18h) share similiar arch with AMD Family 17h
* Mon Mar 25 2019 christian.voegl@suse.com
- Update to version 1.62:
  * mcelog: Fix memory controller bank channel mappings for Skylake
  * mcelog: update tests for new error code
  * mcelog: Add decoding for Optane DC persistent memory mode
  * mcelog: Deduce channel number for Haswell/Broadwell/Skylake systems
- Change mcelog.spec to use autosetup
* Fri Sep 21 2018 opensuse-packaging@opensuse.org
  (by trenn@suse.de)
- Update to version 1.60 (fate#326221):
  * Turn back rb_color field into unsigned long
  * trigger: add a sync argument for waiting trigger child process exit
  * page: trigger: add pre/post sync trigger when doing soft memory offline
  * fixed build errors for some lose code when merging code
  * transfer the page address to pre/post-sync-trigger scripts
  * mcelog: Fix "--ascii" parsing to cope with change in kernel output since v4.10
  * Remove now unused local variable
  * Add scripts file to do MCA error code validation for a selected CPU model
  * Add license file
  * mcelog: Improve decoding for APEI reported errors
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Jul  7 2017 fschnizlein@suse.com
- Update to version 1.53:
  * Add service file
  * dmi: Handle NULL DMI string
  * Compress some fields in mempage.
  * Add coverity fixes
  * Fix typo in man page
  * mcelog: Check whether we successfully changed directory for trigger.
  * mcelog version: Add ability for OS to define version
  * Document .os_release in README
  * Set SO_PASSCRED on listen sockets
  * memutil.h: add missing include for va_list
* Mon Mar 20 2017 trenn@suse.de
- Package also includes fixes for (through previous version updates below):
  * Add mcelog-skylake.patch patch to support Skylake Xeons (fate#319698)
  * Add skylake support (bnc#946734)
  * Avoid warnings at boot up (bsc#920197)
  * Knights Landing (fate#319507)
  * Broadwell Ex and Ep (fate#319697)
  * Different Skylake models (fate#319696)
* Fri Mar  3 2017 mpluskal@suse.com
- Update to version 1.48
  * Fix warning with gcc 6.x
  * Remove obsolete TODO file
  * Small fixes
- Use url for getting sources
* Fri Jan 13 2017 felix.gerling@suse.com
- Version update to 1.47 (fate#321308, fate#320907, fate#321931):
  * Fix PDF links
  * Fix confusing error message
* Sat Dec 17 2016 tchvatal@suse.com
- Version update to 1.46:
  * Various cpu support for new machines
- Refresh patches:
  * add-f10h-support.patch
  * email.patch
- Force build with pic
- Use normal webpage as Url and do not point to git
- Fix build with --as-needed expanded Makefile patch for email.patch
* Fri May  6 2016 trenn@suse.de
- Update to bugfix version 1.36
- Do not start mcelog service based on an udev (/dev/mcelog) rule (bsc#976781)
* Thu Jan 28 2016 trenn@suse.de
- Update to latest version 1.29.
  Mostly little bug fixes.
* Mon Sep 28 2015 trenn@suse.de
- Update to version v124. Adds skylake CPU support and some bug fixes.
* Mon Jun 15 2015 trenn@suse.de
- Update to latest v120 git tag and name the version 1.20:
  New supported CPUs:
  - Add model number for Broadwell-DE
  - Added Knights Landing (Xeon Phi)
  - Add all current Atom cpuids
  - Support Broadwell-U
  - New manpages: mcelog.conf.5 and mcelog.triggers.5
  And quite some undocumented bugfixes, see git log for details
* Fri Jan 23 2015 trenn@suse.de
- Update to version 1.0.8
- Remove patch which got integrated mainline:
  0001-Continue-without-dmi-when-no-SMBIOS-or-SMBIOS-0x0-in.patch
- Fix possible security issue, build service complained about:
  missing-call-to-setgroups-before-setuid
  Add fix_setgroups_missing_call.patch
* Fri Nov 14 2014 crrodriguez@opensuse.org
- While not yet defined, the tmpfiles_create macro takes
  an argument for it to actually work
* Sat Sep 20 2014 crrodriguez@opensuse.org
- mcelog.tmpfiles, mcelog-socket-path.patch, move socket
  and pid file to /run/mcelog directory.
  This update may require reboot as the relevant rpm macro
  tmpfiles_create is not yet in any product.
* Wed Sep  3 2014 trenn@suse.de
- Fixed the architecture tag to %%{ix86} as suggested by:
  Andreas Vetter <asvetter@cip.physik.uni-wuerzburg.de>
* Wed Sep  3 2014 meissner@suse.com
- fixed the architecture tag to %%ix86
* Fri Jul 11 2014 juwolf@suse.com
- Fixed license, GPL-2.0
* Fri Jun 27 2014 juwolf@suse.com
- Added: 0001-Continue-without-dmi-when-no-SMBIOS-or-SMBIOS-0x0-in.patch
  Continue without dmi when no SMBIOS or SMBIOS=0x0 in /sys/firmware/efi/systab, bnc#829862
* Fri May 16 2014 trenn@suse.de
- Add mce decoding support for latest AMD CPUs (bnc#871881).
- Implementation done by Borislav Petkov <bp@suse.de>
  * Add patches/Start-consolidating-AMD-specific-stuff.patch
  * Add add-defines.patch
  * Add add-f10h-support.patch
  * Add add-f11h-support.patch
  * Add add-f12h-support.patch
  * Add add-f14h-support.patch
  * Add add-f15h-support.patch
  * Add add-f16h-support.patch
* Mon Apr 28 2014 trenn@suse.de
- Update to latest git tag v101.
- Mainline decided to finally do a version upgrade to v101
- Remove v1.1 again, obsolete it and go for version v102
- Some important fixes in the latest update:
  - bnc#873159
  - bnc#873725
* Sun Oct 27 2013 crrodriguez@opensuse.org
- Cleanup spec file
- activate mcelog service via udev+systemd combo, if the kernel
  registers a /dev/mcelog device the service will be automatically
  started.
- drop sysvinit scripts, add appropiate %%pre %%post invocations
  of the needed systemd macros.
* Tue Oct 15 2013 trenn@suse.de
- Updated to latest git HEAD:
    commit c7bf28088f056925c04d4fd5768504c59bbf19c4
    Author: Robin Holt <robinmholt@gmail.com>
    Date:   Mon Sep 16 04:30:02 2013 -0500
  Because upstream does not use proper tags/revisions, I now
  versioned this one mcelog-1.1
* Fri Feb 22 2013 rmilasan@suse.com
- Install mcelog.service accordingly (/usr/lib/systemd for 12.3
  and up or /lib/systemd for older versions).
* Thu Aug 16 2012 trenn@suse.de
- bnc#774226 mcelog + systemd: won't start without MCELOG_ADMIN_EMAIL set
- fix uninitialized variable mail_setup
* Wed Jul 18 2012 trenn@suse.de
- Also build mcelog packages for i386 (bnc#770726)
* Mon Apr 23 2012 avm-xandry@yandex.ru
- Fixed description in init-file.
* Wed Nov 23 2011 crrodriguez@opensuse.org
- Add systemd unit.
* Wed Aug 17 2011 ro@suse.de
- update to GIT of today (6e4e2a000124f08f1a4e3791c2b02ec9ae6af393)
- many bugfixes
- Implement re-parsing of mcelog output in ASCII
- Add support for non-page aligned EFI Configuration Tables
- Add --debug-numerrors
- Add decoder for corrected XEN events to --ascii
- Correctly log kernel supplied time
- record the trigger info in the log
- mcelog: Implement dmi decoding for UEFI
- mcelog: Add usage information to mcelog for --ignorenodev
- Fix length calculation of SMBIOS mapping
- change disclaimer
- explictly spell out corrected errors
* Sat Jul  2 2011 trenn@suse.de
- Update to latest git version (fate#311830)
  Unfortunately versions have not been increased, latest tag
  still is 1.0-pre3 (same as 1 year ago), therefore the date
  is included in the version. I try to push maintainers to
  increase the version number.
- Invert logic of db prefill messages -> info if it works, silent
  if not
* Tue Jun  7 2011 trenn@suse.de
- Remove test email address from config
* Mon Oct 25 2010 trenn@suse.de
- Add Sandybridge/Westmere decode support
- Fix domainname for email notification
- Update to latest git version
* Tue Apr  6 2010 trenn@suse.de
- Update to latest git version having quite some fixes (no features):
  - Fixed some memleaks and made app valgrind conform
  - Fixed theoretical DoS attack (bnc#586241)
  - Added support of additional cpus
  - Fixed a lot messages (in manpage, in triggers, in README, ...)
* Thu Feb 18 2010 ro@suse.de
- Update to version 1.0pre3
  - Boxboro-EX enhancements
  - Bugfixes
  Minor pidfile handling adjusting in service file
- Added missing conf file and trigger scripts
* Thu Dec  3 2009 trenn@suse.de
- Minor .spec and init script fixes/cleanups
* Thu Dec  3 2009 trenn@suse.de
- Add service parts:
  - let mcelog --daemon handle pid file in /var/run/mcelog.pid
  - add insserv logic
  - remove cron.daily script in update case
* Fri Nov 27 2009 trenn@suse.de
- Update to latest git version (called it 1.0pre1 myself, may differ
  with a possible public 1.0pre1 version), this includes
  following new featues:
  - yellow bit support
  - page predictive failure analysis support
  - Initial memdb support
    This allows to account memory errors in memory in daemon mode
    And a lot more...
* Fri Oct  2 2009 trenn@suse.de
- Update to latest git version (0.9pre)
  Introduces mcelog damon mode, service file will follow in an
  extra commit.
* Fri Jan  9 2009 olh@suse.de
- use ExclusiveArch as in /SRC/arch/
* Sat Sep 27 2008 trenn@suse.de
- fate #304279 mcelog support for Tigerton/Dunnington
  Patch is from Andi himself with this statement:
  While it looks large most of it is just new tables.
* Mon May 29 2006 ak@suse.de
- decode intel thermal events too (#179327)
* Fri May  5 2006 ak@suse.de
- Update to 0.7.  This fixes
  - Fix --dmi option (#166324)
  - Incorporate old patches
* Fri Mar  3 2006 ak@suse.de
- Avoid cosmetic problem in --filter (#153347)
* Wed Feb  8 2006 ak@suse.de
- update to mcelog 0.6
  * Fixes bugs (#148869, #137985)
  * Adds --dmi option to map addresses to DIMMs using SMBIOS
    (default to off)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 sf@suse.de
- update to version 0.5
  * Clarify --ascii in the manpage
  * Support for AMD K8 Revision F machine check DRAM error
  thresholding
* Fri Feb 11 2005 ak@suse.de
- Use RPM_OPT_FLAGS
- Improve description again
* Thu Feb 10 2005 ak@suse.de
- mcelog-0.4:
  * add support to decode AMD K8 (Opteron/Athlon64/AthlonFX) and
    Intel P4 (Xeon and Pentium 4) events
  * add --ascii option to decode machine check panic information
- Rewrite description in .spec file
* Wed Jun  9 2004 ak@suse.de
- memlog-0.2:
  * fix mcelog looping (#41863)
  * Add GPL notices
* Thu Mar 25 2004 sf@suse.de
- initial version
- fixes #36898
